(function() {
	eb.ui = {};
	
	//Function to return network status
	eb.ui.returnNetworkStatus = function() {
		if (Titanium.Network.networkType == Titanium.Network.NETWORK_NONE)
		{
			return false;
		}
		else
		{
			return true;
		}
	}
	
	//Function to alert when no network status
	eb.ui.alertNetworkStatus = function() {
		var alertDialog = Titanium.UI.createAlertDialog({
			title:'Network Error.',
			message: 'Internet connection appears to be offline.',
			buttonNames:['OK']
		});
		alertDialog.show();
	}
	
	//Function to create splash screen
	eb.ui.createSplashScreen = function(){
		var splashWin = Titanium.UI.createWindow({
			backgroundColor:'black',
			navBarHidden:true
		});
		
		var splashImage = Ti.UI.createImageView();
		
		var landscapeImageName;
		var portraitImageName;
		
		//We need to do this because the simulator see these files in different locations then the phone
		if (Ti.Platform.model=='Simulator')
		{
			portraitImageName = 'iphone/Default-Portrait.png';
			landscapeImageName = 'iphone/Default-Landscape.png';
		}
		else
		{
			portraitImageName = 'Default-Portrait.png';
			landscapeImageName = 'Default-Landscape.png';
		}
		
		//Adjust splash screen image based off of orientation
		if (getOrientation(Ti.UI.orientation) == 'portrait')
		{
			splashImage.image = portraitImageName;
		}
		else if (getOrientation(Ti.UI.orientation) == 'landscape')
		{
			splashImage.image = landscapeImageName;
		}
		else 
		{
			splashImage.image = portraitImageName;
		}
		
		/*
		Ti.Gesture.addEventListener('orientationchange', function(){
			if (getOrientation(Ti.UI.orientation) == 'portrait')
			{
				splashImage.image = portraitImageName;
			}
			else if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				splashImage.image = landscapeImageName;
			}
			else{}
		});		
		*/
		
		splashWin.add(splashImage);
		
		return splashWin;
	}
	
	//Function to create main application tab group
	eb.ui.createApplicationTabGroup = function() {
		var tabGroup = Titanium.UI.createTabGroup();  
		
		var insightsWin = eb.ui.createInsightsWin();
		var calculatorsWin = eb.ui.createCalculatorsWin();
		var careersWin = eb.ui.createCareersWin();
		var eventsWin = eb.ui.createEventsWin();
		var aboutWin = eb.ui.createAboutWin();
		
		//Create all of the tabs
		eb.insightsTab = Titanium.UI.createTab({
		  title: 'Insights',
		  icon: 'images/icons/notepad.png',
		  window: insightsWin
		});
		eb.calculatorsTab = Titanium.UI.createTab({
		  title: 'Calculators',
		  icon: 'images/icons/calculator.png',
		  window: calculatorsWin
		});
		eb.careersTab = Titanium.UI.createTab({
		  title: 'Careers',
		  icon: 'images/icons/suitcase.png',
		  window: careersWin
		});
		eb.eventsTab = Titanium.UI.createTab({
		  title: 'Events',
		  icon: 'images/icons/calendar.png',
		  window: eventsWin
		});
		
		eb.aboutTab = Titanium.UI.createTab({
		  title: 'About Us',
		  icon: 'images/icons/coffee.png',
		  window: aboutWin
		});
		
		eb.calculatorsTab.addEventListener('blur', function(e){
			//Close indicator just in case on is running when we change tabs.
			Titanium.App.fireEvent(hideIndicator());
		});
		
		eb.careersTab.addEventListener('blur', function(e){
			//Close indicator just in case on is running when we change tabs.
			Titanium.App.fireEvent(hideIndicator());
		});
		
		//Add tabs to group
		tabGroup.addTab(eb.insightsTab);
		tabGroup.addTab(eb.calculatorsTab);
		tabGroup.addTab(eb.careersTab);
		tabGroup.addTab(eb.eventsTab);
		tabGroup.addTab(eb.aboutTab);

		tabGroup.addEventListener('click', function(e){
			Ti.App.fireEvent('closeDetailWindow');
		});	
		return tabGroup;
	}
	
	//Function to create email button for insights and events
	eb.ui.createEmailHeaderButton = function(emailSubject, emailHtml)
	{
		var emailHeaderButton = Ti.UI.createButton({
			width:24,
			height:24,
			backgroundImage: 'images/email.png',
		});

		//We are setting the left so that the animation is fluid with the window when it closes
		if (getOrientation(Ti.UI.orientation) == 'landscape')
		{
			emailHeaderButton.left = 985;
		}
		else if (getOrientation(Titanium.UI.orientation) == 'portrait')
		{
			emailHeaderButton.left = 729;
		}
		//Set the orientation change listener to move icon, (using left to allow smooth animation when removing wndow)
		Ti.Gesture.addEventListener('orientationchange', function(){
			if (getOrientation(Ti.UI.orientation) == 'portrait')
			{
				emailHeaderButton.left = 729;
			}
			else if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				emailHeaderButton.left = 985;
			}
		});		

		return emailHeaderButton;
	}
	
	//Function to create the banner depending on which tab/orientation they are on
	eb.ui.createBanner = function(/*string*/ mytab) {
		var bannerView = Titanium.UI.createView({
			top:0,
			left:0,
			height:150,
			backgroundColor:'black'
		});
		
		//Get current orientation
		var orientation = getOrientation(Titanium.UI.orientation);
		
		var bannerImgView = Titanium.UI.createImageView({
			top:0,
			left:0,
			height:150
		});
		
		if  (mytab == 'insights')
		{
			if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				bannerImgView.image = 'images/banners/InsightsLandscape.png';
			}
			else if (getOrientation(Titanium.UI.orientation) == 'portrait')
			{
				bannerImgView.image = 'images/banners/InsightsPortrait.png';
			}
		}
		if (mytab == 'calculators')
		{
			if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				bannerImgView.image = 'images/banners/CalculatorsLandscape.png';
			}
			else if (getOrientation(Titanium.UI.orientation) == 'portrait')
			{
				bannerImgView.image = 'images/banners/CalculatorsPortrait.png';
			}
		}
		else if  (mytab == 'careers')
		{	
			if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				bannerImgView.image = 'images/banners/CareersLandscape.png';
			}
			else if (getOrientation(Titanium.UI.orientation) == 'portrait')
			{
				bannerImgView.image = 'images/banners/CareersPortrait.png';
			}
		}
		else if  (mytab == 'events')
		{
			if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				bannerImgView.image = 'images/banners/EventsLandscape.png';
			}
			else if (getOrientation(Titanium.UI.orientation) == 'portrait')
			{
				bannerImgView.image = 'images/banners/EventsPortrait.png';
			}
		}
		else if  (mytab == 'aboutus')
		{
			if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				bannerImgView.image = 'images/banners/AboutUsLandscape.png';
			}
			else if (getOrientation(Titanium.UI.orientation) == 'portrait')
			{
				bannerImgView.image = 'images/banners/AboutUsPortrait.png';
			}
		}
		
		//Create banner button for Linked In
		var linkedInButton = Titanium.UI.createButton({
			width:'auto',
			height:'auto',
			image: 'images/banners/LinkedIn.png',
			top:13,
			right:43,
			borderRadius:5
		});
		
		linkedInButton.addEventListener('click',function()
		{
			if (eb.ui.returnNetworkStatus() == true)
			{		
				var linkedInWindow = eb.ui.createModalWebView('LinkedIn');
				linkedInWindow.open({
					modal:true,
					modalTransitionStyle:'Cover Vertical',
					modalStyle:'Fullscreen',
					navBarHidden:false
				});
			}
			else
			{
				eb.ui.alertNetworkStatus();
			}
		});
		
		//Create banner button for Facebook
		var facebookButton = Titanium.UI.createButton({
			width:'auto',
			height:'auto',
			image: 'images/banners/Facebook.png',
			top:13,
			right:18,
			borderRadius:5
		});
		
		facebookButton.addEventListener('click',function()
		{
			if (eb.ui.returnNetworkStatus() == true)
			{
				var faceBookWindow = eb.ui.createModalWebView('Facebook');
				faceBookWindow.open({
					modal:true,
					modalTransitionStyle:'Cover Vertical',
					modalStyle:'Fullscreen',
					navBarHidden:false
				});
			}
			else
			{
				eb.ui.alertNetworkStatus();
			}
		});
		
		bannerView.add(bannerImgView);
		bannerView.add(linkedInButton);
		bannerView.add(facebookButton);

		
		//Set the orientation change listener to swap banners
		Ti.Gesture.addEventListener('orientationchange', function(){
			if (getOrientation(Ti.UI.orientation) == 'portrait')
			{
				if  (mytab == 'insights')
				{
					bannerImgView.image = 'images/banners/InsightsPortrait.png';
				}
				if (mytab == 'calculators')
				{
					bannerImgView.image = 'images/banners/CalculatorsPortrait.png';
				}
				else if  (mytab == 'careers')
				{
					bannerImgView.image = 'images/banners/CareersPortrait.png';
				}
				else if  (mytab == 'events')
				{
					bannerImgView.image = 'images/banners/EventsPortrait.png';
				}
				else if  (mytab == 'aboutus')
				{
					bannerImgView.image = 'images/banners/AboutUsPortrait.png';
				}
			}
			else if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				if  (mytab == 'insights')
				{
					bannerImgView.image = 'images/banners/InsightsLandscape.png';
				}
				if (mytab == 'calculators')
				{
					bannerImgView.image = 'images/banners/CalculatorsLandscape.png';
				}
				else if  (mytab == 'careers')
				{
					bannerImgView.image = 'images/banners/CareersLandscape.png';
				}
				else if  (mytab == 'events')
				{
					bannerImgView.image = 'images/banners/EventsLandscape.png';
				}
				else if  (mytab == 'aboutus')
				{
					bannerImgView.image = 'images/banners/AboutUsLandscape.png';
				}
			}
			else{}
		})
		
		return bannerView;

	};
	
	eb.ui.createModalWebView = function(/* string */ site){
		var modalWin = Titanium.UI.createWindow({
		  title: site,
		});
		
		var modalWebView = Ti.UI.createWebView({
			top:0
		});
		
		if (site == 'LinkedIn')
		{
			modalWebView.url = "http://www.linkedin.com/company/eide-bailly-llp"
		}
		if (site == 'Facebook')
		{
			modalWebView.url = "http://www.facebook.com/eidebailly"
		}
		
		var closeModalButton = Ti.UI.createButton({
			title:'Close'
		});
		
		closeModalButton.addEventListener('click', function(e){
			modalWin.close();
		});
			
		modalWin.setRightNavButton(closeModalButton);
		modalWin.add(modalWebView);
	
		return modalWin;
		
	};
	
	eb.ui.createInsightsWin = function() {
		var insightsWin = Titanium.UI.createWindow({
		  title: 'Insights',
		  navBarHidden:true
		});
		
		//Create search bar
		var search = Titanium.UI.createSearchBar({
			barColor:'#385292',
			showCancel:false,
			hintText:'search',
		 
		});
		
		search.addEventListener('change', function(e)
		{
		e.value; // search string as user types
		});
		search.addEventListener('return', function(e)
		{
		search.blur();
		});
		search.addEventListener('cancel', function(e)
		{
		search.blur();
		});
		
		// create table view
		var insightsTableview = Titanium.UI.createTableView({
			top:150,
			search:search,
			filterAttribute:'searchField'
		});
		
		Ti.App.addEventListener('populateInsights', function(data){
			var insightData = JSON.parse(data.responseText);
			
			//Empty array for our table view
			var insightTableData = [];
			
			for (var i = 0; i < insightData.length; i++)
			{
				
				var insightRow = Ti.UI.createTableViewRow({
					height:'auto',
					className:'insightcls'
				});
				
				//Set the ID to a custom field for the listener
				insightRow.insightID = insightData[i].ID;
				
				//Concatenate searchable fields to a custom field for the FilterAttribute for search
				insightRow.searchField = insightData[i].Category + ' ' + insightData[i].Title + ' ' + insightData[i].Summary;
				
				var rowLabelDate = eb.fac.makeLabel(insightData[i].PublishDate);
				rowLabelDate.left = 20;
				rowLabelDate.top = 5;
				rowLabelDate.width = 80;
				rowLabelDate.height = 'auto';
			
				var rowLabelCategory = eb.fac.makeItalicLabel(insightData[i].Category, '#9E7F23');
				rowLabelCategory.width = 'auto';
				rowLabelCategory.left = 0;
				rowLabelCategory.height = 'auto';
				rowLabelCategory.top = 4;
			
				var rowLabelTitle = eb.fac.makeBoldLabel(insightData[i].Title, 'black');
				rowLabelTitle.width = 'auto';
				rowLabelTitle.left = 0;
				rowLabelTitle.height = 'auto';
				rowLabelTitle.top = 5;
				
				
				var rowLabelSummary = eb.fac.makeLabel(insightData[i].Summary);
				rowLabelSummary.left = 0;
				rowLabelSummary.width = 'auto';
				rowLabelSummary.height = 'auto';
				rowLabelSummary.top = 3;
				rowLabelSummary.bottom = 10;
				
				var rowAllContentView = Ti.UI.createView({
					layout: 'vertical',
					left: 100,
					top: 0,
					height:'auto',
					right:20
				});
				
				//Add title and summary to horizontal layout
				rowAllContentView.add(rowLabelCategory);
				rowAllContentView.add(rowLabelTitle);
				rowAllContentView.add(rowLabelSummary);
				
				insightRow.add(rowLabelDate);
				insightRow.add(rowAllContentView);
				
				//Push row to rowdata array
				insightTableData.push(insightRow);	
			};
			//Set tableview data
			insightsTableview.setData(insightTableData);	
		});
		
		// create table view event listener
		insightsTableview.addEventListener('click', function(e)
		{
			var rowdata = e.rowData;
			
			var insightsWin = eb.ui.createInsightsDetailWindow(e.rowData.insightID);
			
			// create window open animation
			var a = Titanium.UI.createAnimation();
			a.left = 0;
			a.duration = 300;
			
			insightsWin.open(a);
		});
		
		//If there is an internet connection populate the table
		if (eb.ui.returnNetworkStatus() == true)
		{
			eb.net.getInsights();
		}
		
		//Set event listener network connection change
		Titanium.Network.addEventListener('change', function(e)
		{
			if (eb.ui.returnNetworkStatus() == true)
			{
				eb.net.getInsights();
			}
		});
		
		//Set event listener for resume from sleep to re-populate table
		Ti.App.addEventListener('resume', function()
		{
			if (eb.ui.returnNetworkStatus() == true)
			{
				eb.net.getInsights();
			}
		})
		
		insightsWin.add(eb.ui.createBanner('insights'));
		//Add table to window
		insightsWin.add(insightsTableview);
		
		return insightsWin;
	}
	
	
	
	eb.ui.createEventsWin = function() {
		var eventsWin = Titanium.UI.createWindow({
		  title: 'Events',
		  navBarHidden:true
		});
		
		//Create header row
		var eventsHeaderView = Ti.UI.createView({
			top:150,
			height:50,
			backgroundColor:'black'
		});
		
		var eventsHeaderLabelType = eb.fac.makeBoldLabel('Type', 'white');
		eventsHeaderLabelType.left = 20;

		var eventsHeaderLabelDate = eb.fac.makeBoldLabel('Date', 'white');
		eventsHeaderLabelDate.left = 120;

		var eventsHeaderLabelLocation = eb.fac.makeBoldLabel('Location', 'white');
		eventsHeaderLabelLocation.left = 220;

		var eventsHeaderLabelEvent = eb.fac.makeBoldLabel('Event', 'white');
		eventsHeaderLabelEvent.left = 400;

		eventsHeaderView.add(eventsHeaderLabelType);
		eventsHeaderView.add(eventsHeaderLabelDate);
		eventsHeaderView.add(eventsHeaderLabelLocation);
		eventsHeaderView.add(eventsHeaderLabelEvent);
		
		//Create search bar
		var search = Titanium.UI.createSearchBar({
			barColor:'#385292',
			showCancel:false,
			hintText:'search',
		 
		});
		
		search.addEventListener('change', function(e)
		{
		e.value; // search string as user types
		});
		search.addEventListener('return', function(e)
		{
		search.blur();
		});
		search.addEventListener('cancel', function(e)
		{
		search.blur();
		});
		
		// create table view
		var eventsTableview = Titanium.UI.createTableView({
			top:200,
			search:search,
			filterAttribute:'searchField'
		});
		

		Ti.App.addEventListener('populateEvents', function(data){
			var eventData = JSON.parse(data.responseText);
		
			//Empty array for our table view
			var eventTableData = [];
		
			for (var i = 0; i < eventData.length; i++)
			{
				var eventRow = Ti.UI.createTableViewRow({
					className:'eventcls'
				});
				
				//Set the ID to a custom field for the listener
				eventRow.eventID = eventData[i].ID;
				
				//Concatenate searchable fields to a custom field for the FilterAttribute for search
				eventRow.searchField = eventData[i].Type + ' ' + eventData[i].Location + ' ' + eventData[i].Title;
				
				var rowView = Ti.UI.createView();
				
				var rowLabelType = eb.fac.makeLabel(eventData[i].Type);
				rowLabelType.left = 20;
				rowLabelType.height = 'auto';
				
				var rowLabelDate = eb.fac.makeLabel(eventData[i].Date);
				rowLabelDate.left = 120;
				rowLabelDate.height = 'auto';

				var rowLabelLocation =  eb.fac.makeLabel(eventData[i].Location);
				rowLabelLocation.left = 220;
				rowLabelLocation.height = 'auto';
				
				var rowLabelEvent = eb.fac.makeLabel(eventData[i].Title);
				rowLabelEvent.left = 400;
				rowLabelEvent.height = 'auto';
				rowLabelEvent.width = 'auto';
				
				eventRow.add(rowLabelType);
				eventRow.add(rowLabelDate);
				eventRow.add(rowLabelLocation);
				eventRow.add(rowLabelEvent);
				
				//Push row to rowdata array
				eventTableData.push(eventRow);
			};

			//Set tableview data
			eventsTableview.setData(eventTableData);
		});
		
		// create table view event listener
		eventsTableview.addEventListener('click', function(e)
		{
			var rowdata = e.rowData;
			
			var eventsDetailWin = eb.ui.createEventsDetailWindow(e.rowData.eventID);
			
			// create window open animation
			var a = Titanium.UI.createAnimation();
			a.left = 0;
			a.duration = 300;
			

			eventsDetailWin.open(a);
		});
		
		//If there is an internet connection populate the table
		if (eb.ui.returnNetworkStatus() == true)
		{
			eb.net.getEvents();
		}
		
		//Set event listener network connection change
		Titanium.Network.addEventListener('change', function(e)
		{
			if (eb.ui.returnNetworkStatus() == true)
			{
				eb.net.getEvents();
			}
		});
		
		//Set event listener for resume from sleep to re-populate table
		Ti.App.addEventListener('resume', function()
		{
			if (eb.ui.returnNetworkStatus() == true)
			{
				eb.net.getEvents();
			}
		})
		
		//Add the table to the window
		eventsWin.add(eventsTableview);
		
		//Add banner and header
		eventsWin.add(eb.ui.createBanner('events'));
		eventsWin.add(eventsHeaderView);
		
		return eventsWin;
	}
	
	eb.ui.createCalculatorsWin = function() {
		var calculatorsWin = Titanium.UI.createWindow({
		  title: 'Calculators',
		  navBarHidden:true
		});
		
		var emailButton = eb.ui.createEmailHeaderButton();
		emailButton.top = 160;
		
		var emailDialog = Titanium.UI.createEmailDialog();
		emailDialog.setSubject('Calculators - from Eide Bailly Mobile');
		//Default the message body
		emailDialog.setMessageBody('I found this calculator on the Eide Bailly Mobile iPad App and thought you might find it useful. <br><br>http://www.eidebailly.com/calculators.html');
		emailDialog.setHtml(true);
		
		emailButton.addEventListener('click',function()
		{
			emailDialog.open();
		});
		
		var calcWebView = Ti.UI.createWebView({
			top:186,
			left:20,
			right:20,
			url:"http://www.eidebailly.com/mobile/calculators.html",
			visible:false,
			scalesPageToFit:false
		});
				
		calculatorsWin.add(eb.ui.createBanner('calculators'));
		calculatorsWin.add(emailButton);
		calculatorsWin.add(calcWebView);
		
		calcWebView.addEventListener('beforeload', function(e){
			Titanium.App.fireEvent(showIndicator());
			//So we don't see default activity indicator
			calcWebView.visible = false;
			emailButton.visible = false;
		});
		
		calcWebView.addEventListener('load', function(e){
			Titanium.App.fireEvent(hideIndicator());
			calcWebView.visible = true;
			emailButton.visible = true;

			//Set the email button to mail the current calculator
			emailDialog.setMessageBody(e.url.replace('/mobile', ''));
		});
		
		return calculatorsWin;
	};
	
	eb.ui.createCareersWin = function() {
		var careersWin = Titanium.UI.createWindow({
		  title: 'Careers',
		  navBarHidden:true
		});

		var careerWebView = Ti.UI.createWebView({
			top:150,
			left:20,
			right:20,
			url:"http://www.eidebailly.com/mobile/careers.html",
			visible:false,
			scalesPageToFit:false
		});
				
		careersWin.add(eb.ui.createBanner('careers'));
		careersWin.add(careerWebView);
		
		careerWebView.addEventListener('beforeload', function(e){
			Titanium.App.fireEvent(showIndicator());
			//So we don't see default activity indicator
			careerWebView.visible = false;
		});
		
		careerWebView.addEventListener('load', function(e){
			Titanium.App.fireEvent(hideIndicator());
			careerWebView.visible = true;
		});
		
		return careersWin;
	};
	
	eb.ui.createAboutWin = function() {
		var aboutWin = Titanium.UI.createWindow({
		  title: 'About Us',
		  navBarHidden:true
		});
		
		eb.net.getAboutDetail();
		
		Ti.App.addEventListener('populateAboutDetail', function(data){
			var aboutData = JSON.parse(data.responseText);
			
			/*
			var emailButton = eb.ui.createEmailHeaderButton();
			emailButton.top = 160;
			
			var emailDialog = Titanium.UI.createEmailDialog();
			emailDialog.setSubject('Eide Bailly At-A-Glance - from Eide Bailly Mobile');		
			emailDialog.setMessageBody(aboutData.FactsAndFigures);
			emailDialog.setHtml(true);
			
			emailButton.addEventListener('click',function()
			{
				emailDialog.open();
			});
			*/
			
			//Create full links from relative links for facts and figures, use esc character on slahes
			var resourcesFullLinks = aboutData.Resources.replace(/\/media\//gi, 'http://www.eidebailly.com/media/')
			
			var aboutResourcesWebview = eb.fac.makeStyledNoScrollWebView(myBrowserLinkConverter(resourcesFullLinks));
			aboutResourcesWebview.top = 160;
			aboutResourcesWebview.left = 20;
			aboutResourcesWebview.width = 200;
		
			
			var aboutFactsAndFiguresWebview = eb.fac.makeStyledNoScrollWebView(aboutData.FactsAndFigures);
			aboutFactsAndFiguresWebview.top = 160;
			aboutFactsAndFiguresWebview.left = 220;
			
			//Adjust width of webview based of orientation, quirky issue when going from landscape to portrait caused con tent to be cut off
			if (getOrientation(Ti.UI.orientation) == 'portrait')
			{
				aboutFactsAndFiguresWebview.width = 528;
			}
			else if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				aboutFactsAndFiguresWebview.width = 784;
			}
			Ti.Gesture.addEventListener('orientationchange', function(){
				if (getOrientation(Ti.UI.orientation) == 'portrait')
				{
					aboutFactsAndFiguresWebview.width = 528;
				}
				else if (getOrientation(Ti.UI.orientation) == 'landscape')
				{
					aboutFactsAndFiguresWebview.width = 784;
				}
			});	
			
			//Create vertical rule row
			var aboutVerticalRuleView = Ti.UI.createView({
				top:160,
				bottom:5,
				backgroundColor:'black',
				width:1,
				left:210,
				borderRadius:2
			});

			aboutWin.add(aboutVerticalRuleView);
			
			aboutWin.add(aboutResourcesWebview);	
			aboutWin.add(aboutFactsAndFiguresWebview);	
			
		});
		
		//Add banner
		aboutWin.add(eb.ui.createBanner('aboutus'));
		
		return aboutWin;
	}
	
	
	eb.ui.createEventsDetailWindow = function(/*int*/ id) {
		var eventsDetailWin = Titanium.UI.createWindow({
			backgroundColor:'white',
			top:150,
			bottom:50
		});
		
		//Set the window off screen initially so we can slide it in		
		if (getOrientation(Ti.UI.orientation) == 'landscape')
		{
			eventsDetailWin.left = 1024;
		}
		else if (getOrientation(Titanium.UI.orientation) == 'portrait')
		{
			eventsDetailWin.left = 768;
		}
		
		//Create header row
		var eventsHeaderView = Ti.UI.createView({
			top:0,
			height:50,
			backgroundColor:'#181818'
		});
		
		var closeEventsDetailButtonLabel = eb.fac.makeHeaderLabel('Back', 'white');
		closeEventsDetailButtonLabel.left = 17;
		
		var closeEventsDetailButton = Ti.UI.createButton({
			top:10,
			left:10,
			width:65,
			height:30,
			backgroundImage:'images/back.png'
		});
		
		closeEventsDetailButton.add(closeEventsDetailButtonLabel);
		
		closeEventsDetailButton.addEventListener('click', function(e){
			
			// create window open animation
			var a = Titanium.UI.createAnimation();
			
			if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				a.left = 1024;
			}
			else if (getOrientation(Titanium.UI.orientation) == 'portrait')
			{
				a.left = 768;
			}
			
			a.duration = 300;
			
			eventsDetailWin.close(a);
		});
		
		//Add items to the header 
		eventsHeaderView.add(closeEventsDetailButton);
		eventsDetailWin.add(eventsHeaderView);
		
		//Call function to get event detail
		eb.net.getEventDetail(id);
		
		//Add listener to populate detail
		Ti.App.addEventListener('populateEventDetail', function(data){
			var eventData = JSON.parse(data.responseText);
			
			var eventTitleHeader = eb.fac.makeHeaderLabel(eventData.Title, 'white');
			eventTitleHeader.left = 230;
			eventTitleHeader.right = 50;
			eventTitleHeader.height = 'auto';
			
			var emailHeaderButton = eb.ui.createEmailHeaderButton();
			emailHeaderButton.addEventListener('click',function()
			{
				var emailDialog = Titanium.UI.createEmailDialog();
				emailDialog.setSubject(eventData.Title + ' - from Eide Bailly Mobile');
				
				//Create message body
				var eventMessageBody = eventData.Description + '<br>Click <a href="http://www.eidebailly.com/about-us/events/event-details?eventID=' + id + '"">here</a> for more details.'
				
				emailDialog.setMessageBody(eventMessageBody);
				emailDialog.setHtml(true);
				emailDialog.open();
			});
			
			var eventStartLabel = eb.fac.makeBoldLabel('Start Date & Time:', '#9E7F23');
			eventStartLabel.left = 20;
			eventStartLabel.top = 60;
			eventStartLabel.width = 200;
			eventStartLabel.height = 'auto';
			
			var eventStart = eb.fac.makeLabel(eventData.StartDate);
			eventStart.left = 20;
			eventStart.top = 80;
			eventStart.width = 200;
			eventStart.height = 'auto';
			
			var eventEndLabel = eb.fac.makeBoldLabel('Start Date & Time:', '#9E7F23');
			eventEndLabel.left = 20;
			eventEndLabel.top = 110;
			eventEndLabel.width = 200;
			eventEndLabel.height = 'auto';
			
			var eventEnd = eb.fac.makeLabel(eventData.StartDate);
			eventEnd.left = 20;
			eventEnd.top = 130;
			eventEnd.width = 200;
			eventEnd.height = 'auto';
			
			var eventTypeLabel = eb.fac.makeBoldLabel('Type:', '#9E7F23');
			eventTypeLabel.left = 20;
			eventTypeLabel.top = 160;
			eventTypeLabel.width = 200;
			eventTypeLabel.height = 'auto';
			
			var eventType = eb.fac.makeLabel(eventData.Type);
			eventType.left = 20;
			eventType.top = 180;
			eventType.width = 200;
			eventType.height = 'auto';

			var eventLocationLabel = eb.fac.makeBoldLabel('Location:', '#9E7F23');
			eventLocationLabel.left = 20;
			eventLocationLabel.top = 210;
			eventLocationLabel.width = 200;
			eventLocationLabel.height = 'auto';
			
			var eventLocation = eb.fac.makeLabel(eventData.Location);
			eventLocation.left = 20;
			eventLocation.top = 230;
			eventLocation.width = 200;
			eventLocation.height = 'auto';
			
			var eventVenueLabel = eb.fac.makeBoldLabel('Venue:', '#9E7F23');
			eventVenueLabel.left = 20;
			eventVenueLabel.top = 260;
			eventVenueLabel.width = 150;
			eventVenueLabel.height = 'auto';
			
			var eventVenueWebview = eb.fac.makeStyledNoScrollWebView(eventData.Venue);
			
			eventVenueWebview.top = 280;
			eventVenueWebview.left = 20;
			eventVenueWebview.width = 200;
			eventVenueWebview.height = 75;
			eventVenueWebview.touchEnabled = true;

			var eventCostLabel = eb.fac.makeBoldLabel('Cost:', '#9E7F23');
			eventCostLabel.left = 20;
			eventCostLabel.top = 350;
			eventCostLabel.width = 200;
			eventCostLabel.height = 'auto';
			
			var eventCost = eb.fac.makeLabel(eventData.Cost);
			eventCost.left = 20;
			eventCost.top = 370;
			eventCost.width = 200;
			eventCost.height = 'auto';
			
			var eventContactNameLabel = eb.fac.makeBoldLabel('Contact:', '#9E7F23');
			eventContactNameLabel.left = 20;
			eventContactNameLabel.top = 400;
			eventContactNameLabel.width = 200;
			eventContactNameLabel.height = 'auto';

			
			var eventContactName = eb.fac.makeLabel(eventData.ContactName);
			eventContactName.left = 20;
			eventContactName.top = 420;
			eventContactName.width = 200;
			eventContactName.height = 'auto';
			
			if (eventData.RegistrationLink != "")
			{
				//Create button for event registration
				var eventRegButton = Titanium.UI.createButton({
					width:'auto',
					height:'auto',
					image: 'images/GradButtonBlk.png',
					top: 450,
					left: 20
				});
				
				var eventRegButtonLabel = eb.fac.makeBoldLabel('REGISTER NOW', '#FFFFFF');
				eventRegButtonLabel.width = 'auto';
				eventRegButtonLabel.height = 'auto';
				
				eventRegButton.add(eventRegButtonLabel);
				
				eventRegButton.addEventListener('click', function(e){
					Titanium.Platform.openURL(eventData.RegistrationLink);
				});
				
				eventsDetailWin.add(eventRegButton);
			}
			
			//Create vertical rule row
			var eventsVerticalRuleView = Ti.UI.createView({
				top:55,
				bottom:5,
				backgroundColor:'black',
				width:1,
				left:210,
				borderRadius:2
			});

			var contentView = eb.fac.makeStyledWebView(eventData.Description);
			
			contentView.top = 60;
			contentView.left = 230;
			
			//Adjust width of webview based of orientation, quirky issue when going from landscape to portrait caused con tent to be cut off
			if (getOrientation(Ti.UI.orientation) == 'portrait')
			{
				contentView.width = 518;
			}
			else if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				contentView.width = 774;
			}
			Ti.Gesture.addEventListener('orientationchange', function(){
				if (getOrientation(Ti.UI.orientation) == 'portrait')
				{
					contentView.width = 518;
				}
				else if (getOrientation(Ti.UI.orientation) == 'landscape')
				{
					contentView.width = 774;
				}
			});	
			
			eventsHeaderView.add(eventTitleHeader);
			eventsHeaderView.add(emailHeaderButton);
			
			eventsDetailWin.add(eventStartLabel);
			eventsDetailWin.add(eventStart);
			eventsDetailWin.add(eventEndLabel);
			eventsDetailWin.add(eventEnd);
			eventsDetailWin.add(eventTypeLabel);
			eventsDetailWin.add(eventType);
			eventsDetailWin.add(eventLocationLabel);
			eventsDetailWin.add(eventLocation);
			eventsDetailWin.add(eventVenueLabel);
			eventsDetailWin.add(eventVenueWebview);
			eventsDetailWin.add(eventCostLabel);
			eventsDetailWin.add(eventCost);
			eventsDetailWin.add(eventContactNameLabel);
			eventsDetailWin.add(eventContactName);
			eventsDetailWin.add(eventsVerticalRuleView);
			eventsDetailWin.add(contentView);
		});
		
		
		eb.eventsTab.addEventListener('blur', function(e){			
			eventsDetailWin.close();
			eventsDetailWin = null;
		});
		
		return eventsDetailWin;
	}
	
	eb.ui.createInsightsDetailWindow = function(/*int*/ id) {
		var insightsDetailWin = Titanium.UI.createWindow({
			backgroundColor:'white',
			top:150,
			bottom:50
		});
		
		Ti.API.info(Titanium.Platform.availableMemory);
		
		//Set the window off screen initially so we can slide it in		
		if (getOrientation(Ti.UI.orientation) == 'landscape')
		{
			insightsDetailWin.left = 1024;
		}
		else if (getOrientation(Titanium.UI.orientation) == 'portrait')
		{
			insightsDetailWin.left = 768;
		}
		
		//Create header row
		var insightsHeaderView = Ti.UI.createView({
			top:0,
			height:50,
			backgroundColor:'#181818'
		});
		
		var closeInsightsDetailButtonLabel = eb.fac.makeHeaderLabel('Back', 'white');
		closeInsightsDetailButtonLabel.left = 17;
		
		var closeInsightsDetailButton = Ti.UI.createButton({
			top:10,
			left:10,
			width:65,
			height:30,
			backgroundImage:'images/back.png'
		});
		
		closeInsightsDetailButton.add(closeInsightsDetailButtonLabel);
		
		closeInsightsDetailButton.addEventListener('click', function(e){
			
			// create window open animation
			var a = Titanium.UI.createAnimation();
			
			if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				a.left = 1024;
			}
			else if (getOrientation(Titanium.UI.orientation) == 'portrait')
			{
				a.left = 768;
			}
			a.duration = 300;
			
			insightsDetailWin.close(a);
		});
		
		//Add items to the header 
		insightsHeaderView.add(closeInsightsDetailButton);
		insightsDetailWin.add(insightsHeaderView);
		
		
		//Call function to get event detail
		eb.net.getInsightDetail(id);
		
		//Add listener to populate detail
		Ti.App.addEventListener('populateInsightDetail', function(data){
			
			var insightData = JSON.parse(data.responseText);
		
			var insightTitleHeader = eb.fac.makeHeaderLabel(insightData.Title, 'white');
			insightTitleHeader.left = 230;
			insightTitleHeader.right = 50;
			insightTitleHeader.height = 'auto';
			
			var emailHeaderButton = eb.ui.createEmailHeaderButton();
			emailHeaderButton.addEventListener('click',function()
			{
				var emailDialog = Titanium.UI.createEmailDialog();
				emailDialog.setSubject(insightData.Title + ' - from Eide Bailly Mobile');
				emailDialog.setMessageBody(insightData.Content);
				emailDialog.setHtml(true);
				emailDialog.open();
			});

			var contactImage = Ti.UI.createImageView({
				image:'http://www.eidebailly.com/images/employees/profile/' + insightData.ContactPhoto,
				borderRadius:0,
				borderWidth:1,
				borderColor:'black',
				defaultImage:'images/ContactPhotoLoading.png'
			});
			contactImage.left = 25;
			contactImage.top = 60;
			contactImage.width = 160;
			contactImage.height = 220;
			
			//Create vertical rule row
			var insightsVerticalRuleView = Ti.UI.createView({
				top:55,
				bottom:5,
				backgroundColor:'black',
				width:1,
				left:210,
				borderRadius:2
			});
			
			var contentView = eb.fac.makeStyledWebView(insightData.Content);
			contentView.top = 60;
			contentView.left = 230;
			
			//Adjust width of webview based of orientation, quirky issue when going from landscape to portrait caused con tent to be cut off
			if (getOrientation(Ti.UI.orientation) == 'portrait')
			{
				contentView.width = 518;
			}
			else if (getOrientation(Ti.UI.orientation) == 'landscape')
			{
				contentView.width = 774;
			}
			Ti.Gesture.addEventListener('orientationchange', function(){
				if (getOrientation(Ti.UI.orientation) == 'portrait')
				{
					contentView.width = 518;
				}
				else if (getOrientation(Ti.UI.orientation) == 'landscape')
				{
					contentView.width = 774;
				}
			});	
			
			//Add dynamic items to the correct views and windows
			insightsHeaderView.add(insightTitleHeader);
			insightsHeaderView.add(emailHeaderButton);
		
			insightsDetailWin.add(contactImage);
			insightsDetailWin.add(insightsVerticalRuleView);
			insightsDetailWin.add(contentView);

		});
		 
		eb.insightsTab.addEventListener('blur', function(e){
			insightsDetailWin.close();
		});
		
		return insightsDetailWin;
	}
})();